Module vfs

Module vfs 

Modules

mount_plugin
mount_table
overlay_fs
root_fs
single_symlink_fs
tar_fs
usage
vfs

Structs

FileSystemPluginRegistry
FileSystemStats
FileSystemUsage
FilesystemEntry
MemoryFileSystem
MemoryFileSystemSnapshot
MemoryFileSystemSnapshotInode
MemoryFileSystemSnapshotMetadata
MountEntry
MountOptions
MountTable
MountedVirtualFileSystem
OpenFileSystemPluginRequest
OverlayFileSystem
PluginError
ReadOnlyFileSystem
RootFileSystem
RootFilesystemDescriptor
RootFilesystemError
RootFilesystemImportLimits
RootFilesystemSnapshot
SingleSymlinkFileSystem
Tiny read-only filesystem whose root inode is a single symbolic link.
TarFileSystem
Read-only filesystem backed by the mount chunk of a .aospkg package.
VfsError
VirtualDirEntry
VirtualStat
VirtualTimeSpec

Enums

AccessTimePolicy
FileType
FilesystemEntryKind
MemoryFileSystemSnapshotInodeKind
OverlayMode
RootFilesystemMode
VirtualUtimeSpec

Constants

DEFAULT_MAX_FILESYSTEM_BYTES
DEFAULT_MAX_INODE_COUNT
MAX_PATH_LENGTH
RENAME_EXCHANGE
RENAME_NOREPLACE
RENAME_WHITEOUT
ROOT_FILESYSTEM_SNAPSHOT_FORMAT
S_IFBLK
S_IFCHR
S_IFDIR
S_IFIFO
S_IFLNK
S_IFREG
XATTR_CREATE
XATTR_LIST_MAX
XATTR_NAME_MAX
XATTR_REPLACE
XATTR_SIZE_MAX

Traits

FileSystemPluginFactory
MountedFileSystem
RootFilesystemResourceLimits
VirtualFileSystem

Functions

decode_snapshot
decode_snapshot_with_import_limits
encode_snapshot
is_supported_root_filesystem_snapshot_format
load_bundled_base_snapshot_with_limits
measure_filesystem_usage
normalize_path
set_xattr_value
validate_path
validate_snapshot_import_limits
validate_xattr_name

Type Aliases

VfsResult